==> cdk8s-plus-17-1.0.0b27.tar.gz: package/lib/ingress-v1beta1.d.ts <==
import { ApiObject } from 'cdk8s';
import { Construct } from 'constructs';
import { Resource, ResourceProps } from './base';
import * as k8s from './imports/k8s';
import { Service } from './service';
/**
 * Properties for `Ingress`.
 *
 * @stability stable
 */
export interface IngressV1Beta1Props extends ResourceProps {
    /**
     * The default backend services requests that do not match any rule.
     *
     * Using this option or the `addDefaultBackend()` method is equivalent to
     * adding a rule with both `path` and `host` undefined.
     *
     * @stability stable
     */
    readonly defaultBackend?: IngressV1Beta1Backend;
    /**
     * Routing rules for this ingress.
     *
     * Each rule must define an `IngressBackend` that will receive the requests
     * that match this rule. If both `host` and `path` are not specifiec, this
     * backend will be used as the default backend of the ingress.
     *
     * You can also add rules later using `addRule()`, `addHostRule()`,
     * `addDefaultBackend()` and `addHostDefaultBackend()`.
     *
     * @stability stable
     */
    readonly rules?: IngressV1Beta1Rule[];
}
/**
 * Ingress is a collection of rules that allow inbound connections to reach the endpoints defined by a backend.
 *
 * An Ingress can be configured to give services
 * externally-reachable urls, load balance traffic, terminate SSL, offer name
 * based virtual hosting etc.
 *
 * @stability stable
 */
export declare class IngressV1Beta1 extends Resource {
    /**
     * The underlying cdk8s API object.
     *
     * @see base.Resource.apiObject
     * @stability stable
     */
    protected readonly apiObject: ApiObject;
    private readonly _rulesPerHost;
    private _defaultBackend?;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props?: IngressV1Beta1Props);
    /**
     * (deprecated) Validate the current construct.
     *
     * This method can be implemented by derived constructs in order to perform
     * validation logic. It is called on all constructs before synthesis.
     *
     * @stability stable
     */
    protected onValidate(): string[];
    /**
     * Defines the default backend for this ingress.
     *
     * A default backend capable of
     * servicing requests that don't match any rule.
     *
     * @param backend The backend to use for requests that do not match any rule.
     * @stability stable
     */
    addDefaultBackend(backend: IngressV1Beta1Backend): void;
    /**
     * Specify a default backend for a specific host name.
     *
     * This backend will be used as a catch-all for requests
     * targeted to this host name (the `Host` header matches this value).
     *
     * @param host The host name to match.
     * @param backend The backend to route to.
     * @stability stable
     */
    addHostDefaultBackend(host: string, backend: IngressV1Beta1Backend): void;
    /**
     * Adds an ingress rule applied to requests to a specific host and a specific HTTP path (the `Host` header matches this value).
     *
     * @param host The host name.
     * @param path The HTTP path.
     * @param backend The backend to route requests to.
     * @stability stable
     */
    addHostRule(host: string, path: string, backend: IngressV1Beta1Backend): void;
    /**
     * Adds an ingress rule applied to requests sent to a specific HTTP path.
     *
     * @param path The HTTP path.
     * @param backend The backend to route requests to.
     * @stability stable
     */
    addRule(path: string, backend: IngressV1Beta1Backend): void;
    /**
     * Adds rules to this ingress.
     *
     * @param rules The rules to add.
     * @stability stable
     */
    addRules(...rules: IngressV1Beta1Rule[]): void;
    private synthRules;
}
/**
 * Options for setting up backends for ingress rules.
 *
 * @stability stable
 */
export interface ServiceIngressV1BetaBackendOptions {
    /**
     * The port to use to access the service.
     *
     * - This option will fail if the service does not expose any ports.
     * - If the service exposes multiple ports, this option must be specified.
     * - If the service exposes a single port, this option is optional and if
     *    specified, it must be the same port exposed by the service.
     *
     * @default - if the service exposes a single port, this port will be used.
     * @stability stable
     */
    readonly port?: number;
}
/**
 * The backend for an ingress path.
 *
 * @stability stable
 */
export declare class IngressV1Beta1Backend {
    private readonly backend;
    /**
     * A Kubernetes `Service` to use as the backend for this path.
     *
     * @param service The service object.
     * @stability stable
     */
    static fromService(service: Service, options?: ServiceIngressV1BetaBackendOptions): IngressV1Beta1Backend;
    private constructor();
    /**
     * @internal
     */
    _toKube(): k8s.IngressBackend;
}
/**
 * Represents the rules mapping the paths under a specified host to the related backend services.
 *
 * Incoming requests are first evaluated for a host match,
 * then routed to the backend associated with the matching path.
 *
 * @stability stable
 */
export interface IngressV1Beta1Rule {
    /**
     * Backend defines the referenced service endpoint to which the traffic will be forwarded to.
     *
     * @stability stable
     */
    readonly backend: IngressV1Beta1Backend;
    /**
     * Host is the fully qualified domain name of a network host, as defined by RFC 3986.
     *
     * Note the following deviations from the "host" part of the URI as
     * defined in the RFC: 1. IPs are not allowed. Currently an IngressRuleValue
     * can only apply to the IP in the Spec of the parent Ingress. 2. The `:`
     * delimiter is not respected because ports are not allowed. Currently the
     * port of an Ingress is implicitly :80 for http and :443 for https. Both
     * these may change in the future. Incoming requests are matched against the
     * host before the IngressRuleValue.
     *
     * @default - If the host is unspecified, the Ingress routes all traffic based
     * on the specified IngressRuleValue.
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path is an extended POSIX regex as defined by IEEE Std 1003.1, (i.e this follows the egrep/unix syntax, not the perl syntax) matched against the path of an incoming request. Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/'.
     *
     * @default - If unspecified, the path defaults to a catch all sending traffic
     * to the backend.
     * @stability stable
     */
    readonly path?: string;
}

==> cdk8s-plus-21-1.0.0b54.tar.gz: package/lib/ingress-v1beta1.d.ts <==
import { ApiObject } from 'cdk8s';
import { Construct } from 'constructs';
import { Resource, ResourceProps } from './base';
import * as k8s from './imports/k8s';
import { ISecret } from './secret';
import { Service } from './service';
/**
 * Properties for `Ingress`.
 *
 * @stability stable
 */
export interface IngressV1Beta1Props extends ResourceProps {
    /**
     * The default backend services requests that do not match any rule.
     *
     * Using this option or the `addDefaultBackend()` method is equivalent to
     * adding a rule with both `path` and `host` undefined.
     *
     * @stability stable
     */
    readonly defaultBackend?: IngressV1Beta1Backend;
    /**
     * Routing rules for this ingress.
     *
     * Each rule must define an `IngressBackend` that will receive the requests
     * that match this rule. If both `host` and `path` are not specifiec, this
     * backend will be used as the default backend of the ingress.
     *
     * You can also add rules later using `addRule()`, `addHostRule()`,
     * `addDefaultBackend()` and `addHostDefaultBackend()`.
     *
     * @stability stable
     */
    readonly rules?: IngressV1Beta1Rule[];
    /**
     * TLS settings for this ingress.
     *
     * Using this option tells the ingress controller to expose a TLS endpoint.
     * Currently the Ingress only supports a single TLS port, 443. If multiple
     * members of this list specify different hosts, they will be multiplexed on
     * the same port according to the hostname specified through the SNI TLS
     * extension, if the ingress controller fulfilling the ingress supports SNI.
     *
     * @stability stable
     */
    readonly tls?: IngressV1Beta1Tls[];
}
/**
 * Ingress is a collection of rules that allow inbound connections to reach the endpoints defined by a backend.
 *
 * An Ingress can be configured to give services
 * externally-reachable urls, load balance traffic, terminate SSL, offer name
 * based virtual hosting etc.
 *
 * @stability stable
 */
export declare class IngressV1Beta1 extends Resource {
    /**
     * The underlying cdk8s API object.
     *
     * @see base.Resource.apiObject
     * @stability stable
     */
    protected readonly apiObject: ApiObject;
    private readonly _rulesPerHost;
    private _defaultBackend?;
    private readonly _tlsConfig;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props?: IngressV1Beta1Props);
    /**
     * (deprecated) Validate the current construct.
     *
     * This method can be implemented by derived constructs in order to perform
     * validation logic. It is called on all constructs before synthesis.
     *
     * @stability stable
     */
    protected onValidate(): string[];
    /**
     * Defines the default backend for this ingress.
     *
     * A default backend capable of
     * servicing requests that don't match any rule.
     *
     * @param backend The backend to use for requests that do not match any rule.
     * @stability stable
     */
    addDefaultBackend(backend: IngressV1Beta1Backend): void;
    /**
     * Specify a default backend for a specific host name.
     *
     * This backend will be used as a catch-all for requests
     * targeted to this host name (the `Host` header matches this value).
     *
     * @param host The host name to match.
     * @param backend The backend to route to.
     * @stability stable
     */
    addHostDefaultBackend(host: string, backend: IngressV1Beta1Backend): void;
    /**
     * Adds an ingress rule applied to requests to a specific host and a specific HTTP path (the `Host` header matches this value).
     *
     * @param host The host name.
     * @param path The HTTP path.
     * @param backend The backend to route requests to.
     * @stability stable
     */
    addHostRule(host: string, path: string, backend: IngressV1Beta1Backend): void;
    /**
     * Adds an ingress rule applied to requests sent to a specific HTTP path.
     *
     * @param path The HTTP path.
     * @param backend The backend to route requests to.
     * @stability stable
     */
    addRule(path: string, backend: IngressV1Beta1Backend): void;
    /**
     * Adds rules to this ingress.
     *
     * @param rules The rules to add.
     * @stability stable
     */
    addRules(...rules: IngressV1Beta1Rule[]): void;
    private synthRules;
    /**
     * @stability stable
     */
    addTls(tls: IngressV1Beta1Tls[]): void;
    private tlsConfig;
}
/**
 * Options for setting up backends for ingress rules.
 *
 * @stability stable
 */
export interface ServiceIngressV1BetaBackendOptions {
    /**
     * The port to use to access the service.
     *
     * - This option will fail if the service does not expose any ports.
     * - If the service exposes multiple ports, this option must be specified.
     * - If the service exposes a single port, this option is optional and if
     *    specified, it must be the same port exposed by the service.
     *
     * @default - if the service exposes a single port, this port will be used.
     * @stability stable
     */
    readonly port?: number;
}
/**
 * The backend for an ingress path.
 *
 * @stability stable
 */
export declare class IngressV1Beta1Backend {
    private readonly backend;
    /**
     * A Kubernetes `Service` to use as the backend for this path.
     *
     * @param service The service object.
     * @stability stable
     */
    static fromService(service: Service, options?: ServiceIngressV1BetaBackendOptions): IngressV1Beta1Backend;
    private constructor();
    /**
     * @internal
     */
    _toKube(): k8s.IngressBackendV1Beta1;
}
/**
 * Represents the rules mapping the paths under a specified host to the related backend services.
 *
 * Incoming requests are first evaluated for a host match,
 * then routed to the backend associated with the matching path.
 *
 * @stability stable
 */
export interface IngressV1Beta1Rule {
    /**
     * Backend defines the referenced service endpoint to which the traffic will be forwarded to.
     *
     * @stability stable
     */
    readonly backend: IngressV1Beta1Backend;
    /**
     * Host is the fully qualified domain name of a network host, as defined by RFC 3986.
     *
     * Note the following deviations from the "host" part of the URI as
     * defined in the RFC: 1. IPs are not allowed. Currently an IngressRuleValue
     * can only apply to the IP in the Spec of the parent Ingress. 2. The `:`
     * delimiter is not respected because ports are not allowed. Currently the
     * port of an Ingress is implicitly :80 for http and :443 for https. Both
     * these may change in the future. Incoming requests are matched against the
     * host before the IngressRuleValue.
     *
     * @default - If the host is unspecified, the Ingress routes all traffic based
     * on the specified IngressRuleValue.
     * @stability stable
     */
    readonly host?: string;
    /**
     * Path is an extended POSIX regex as defined by IEEE Std 1003.1, (i.e this follows the egrep/unix syntax, not the perl syntax) matched against the path of an incoming request. Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/'.
     *
     * @default - If unspecified, the path defaults to a catch all sending traffic
     * to the backend.
     * @stability stable
     */
    readonly path?: string;
}
/**
 * Represents the TLS configuration mapping that is passed to the ingress controller for SSL termination.
 *
 * @stability stable
 */
export interface IngressV1Beta1Tls {
    /**
     * Hosts are a list of hosts included in the TLS certificate.
     *
     * The values in
     * this list must match the name/s used in the TLS Secret.
     *
     * @default - If unspecified, it defaults to the wildcard host setting for
     * the loadbalancer controller fulfilling this Ingress.
     * @stability stable
     */
    readonly hosts?: string[];
    /**
     * Secret is the secret that contains the certificate and key used to terminate SSL traffic on 443.
     *
     * If the SNI host in a listener conflicts with
     * the "Host" header field used by an IngressRule, the SNI host is used for
     * termination and value of the Host header is used for routing.
     *
     * @default - If unspecified, it allows SSL routing based on SNI hostname.
     * @stability stable
     */
    readonly secret?: ISecret;
}
